@@ -487,215 +487,7 @@ panel.stripplot <-
 
 
 
-
-## original panel.bwplot.  Superceded by new version below that
-## supports notches, but keeping around for a while just in case
-## (2008/11/20)
-
-panel.bwplot.old <-
-    function(x, y, box.ratio = 1, box.width = box.ratio / (1 + box.ratio),
-             horizontal = TRUE,
-             pch = box.dot$pch,
-             col = box.dot$col,
-             alpha = box.dot$alpha,
-             cex = box.dot$cex,
-             font = box.dot$font,
-             fontfamily = box.dot$fontfamily,
-             fontface = box.dot$fontface, 
-             fill = box.rectangle$fill,
-             varwidth = FALSE,
-             ...,
-             levels.fos = if (horizontal) sort(unique(y)) else sort(unique(x)),
-             stats = boxplot.stats,
-             coef = 1.5, do.out = TRUE)
-{
-    if (all(is.na(x) | is.na(y))) return()
-    x <- as.numeric(x)
-    y <- as.numeric(y)
-
-    box.dot <- trellis.par.get("box.dot")
-    box.rectangle <- trellis.par.get("box.rectangle")
-    box.umbrella <- trellis.par.get("box.umbrella")
-    plot.symbol <- trellis.par.get("plot.symbol")
-
-    fontsize.points <- trellis.par.get("fontsize")$points
-    cur.limits <- current.panel.limits()
-    xscale <- cur.limits$xlim
-    yscale <- cur.limits$ylim
-
-    if (horizontal)
-    {
-        blist <-
-            tapply(x, factor(y, levels = levels.fos),
-                   stats,
-                   coef = coef,
-                   do.out = do.out)
-        blist.stats <- t(sapply(blist, "[[", "stats"))
-        blist.out <- lapply(blist, "[[", "out")
-        blist.height <- box.width # box.ratio / (1 + box.ratio)
-        if (varwidth)
-        {
-            maxn <- max(table(y))
-            blist.n <- sapply(blist, "[[", "n")
-            blist.height <- sqrt(blist.n / maxn) * blist.height
-        }
-
-        ## box
-
-        lrect(xleft = blist.stats[, 2],
-              xright = blist.stats[, 4],
-              y = levels.fos, 
-              height = blist.height,
-              lwd = box.rectangle$lwd,
-              lty = box.rectangle$lty,
-              col = fill,
-              alpha = box.rectangle$alpha,
-              border = box.rectangle$col)
-
-        ## whiskers
-
-        panel.segments(c(blist.stats[, 2], blist.stats[, 4]),
-                       rep(levels.fos, 2),
-                       c(blist.stats[, 1], blist.stats[, 5]),
-                       rep(levels.fos, 2),
-                       col = box.umbrella$col,
-                       alpha = box.umbrella$alpha,
-                       lwd = box.umbrella$lwd,
-                       lty = box.umbrella$lty)
-        panel.segments(c(blist.stats[, 1], blist.stats[, 5]),
-                       levels.fos - blist.height / 2,
-                       c(blist.stats[, 1], blist.stats[, 5]),
-                       levels.fos + blist.height / 2,
-                       col = box.umbrella$col,
-                       alpha = box.umbrella$alpha,
-                       lwd = box.umbrella$lwd,
-                       lty = box.umbrella$lty)
-
-        ## dot
-
-        if (all(pch == "|"))
-        {
-            panel.segments(blist.stats[, 3],
-                           levels.fos - blist.height / 2,
-                           blist.stats[, 3],
-                           levels.fos + blist.height / 2,
-                           lwd = box.rectangle$lwd,
-                           lty = box.rectangle$lty,
-                           col = box.rectangle$col,
-                           alpha = alpha)
-        }
-        else
-        {
-            panel.points(x = blist.stats[, 3],
-                         y = levels.fos,
-                         pch = pch,
-                         col = col, alpha = alpha, cex = cex,
-                         fontfamily = fontfamily,
-                         fontface = chooseFace(fontface, font),
-                         fontsize = fontsize.points)
-        }
-
-        ## outliers
-
-        panel.points(x = unlist(blist.out),
-                     y = rep(levels.fos, sapply(blist.out, length)),
-                     pch = plot.symbol$pch,
-                     col = plot.symbol$col,
-                     alpha = plot.symbol$alpha,
-                     cex = plot.symbol$cex,
-                     fontfamily = plot.symbol$fontfamily,
-                     fontface = chooseFace(plot.symbol$fontface, plot.symbol$font),
-                     fontsize = fontsize.points)
-    }
-    else
-    {
-        blist <-
-            tapply(y, factor(x, levels = levels.fos),
-                   stats,
-                   coef = coef,
-                   do.out = do.out)
-        blist.stats <- t(sapply(blist, "[[", "stats"))
-        blist.out <- lapply(blist, "[[", "out")
-        blist.height <- box.width # box.ratio / (1 + box.ratio)
-        if (varwidth)
-        {
-            maxn <- max(table(x))
-            blist.n <- sapply(blist, "[[", "n")
-            blist.height <- sqrt(blist.n / maxn) * blist.height
-        }
-
-        ## box
-
-        lrect(ybottom = blist.stats[, 2],
-              ytop = blist.stats[, 4],
-              x = levels.fos, 
-              width = blist.height,
-              lwd = box.rectangle$lwd,
-              lty = box.rectangle$lty,
-              col = fill,
-              alpha = box.rectangle$alpha,
-              border = box.rectangle$col)
-
-        ## whiskers
-
-        panel.segments(rep(levels.fos, 2),
-                       c(blist.stats[, 2], blist.stats[, 4]),
-                       rep(levels.fos, 2),
-                       c(blist.stats[, 1], blist.stats[, 5]),
-                       col = box.umbrella$col,
-                       alpha = box.umbrella$alpha,
-                       lwd = box.umbrella$lwd,
-                       lty = box.umbrella$lty)
-        panel.segments(levels.fos - blist.height / 2,
-                       c(blist.stats[, 1], blist.stats[, 5]),
-                       levels.fos + blist.height / 2,
-                       c(blist.stats[, 1], blist.stats[, 5]),
-                       col = box.umbrella$col,
-                       alpha = box.umbrella$alpha,
-                       lwd = box.umbrella$lwd,
-                       lty = box.umbrella$lty)
-
-        ## dot
-
-        if (all(pch == "|"))
-        {
-            panel.segments(levels.fos - blist.height / 2,
-                           blist.stats[, 3],
-                           levels.fos + blist.height / 2,
-                           blist.stats[, 3],
-                           lwd = box.rectangle$lwd,
-                           lty = box.rectangle$lty,
-                           col = box.rectangle$col,
-                           alpha = alpha)
-        }
-        else
-        {
-            panel.points(x = levels.fos,
-                         y = blist.stats[, 3],
-                         pch = pch,
-                         col = col, alpha = alpha, cex = cex,
-                         fontfamily = fontfamily,
-                         fontface = chooseFace(fontface, font),
-                         fontsize = fontsize.points)
-        }
-
-        ## outliers
-
-        panel.points(x = rep(levels.fos, sapply(blist.out, length)),
-                     y = unlist(blist.out),
-                     pch = plot.symbol$pch,
-                     col = plot.symbol$col,
-                     alpha = plot.symbol$alpha,
-                     cex = plot.symbol$cex,
-                     fontfamily = plot.symbol$fontfamily,
-                     fontface = chooseFace(plot.symbol$fontface, plot.symbol$font),
-                     fontsize = fontsize.points)
-    }
-}
-
-
-
-## modified version that supports notches (based on patch from Mike Kay)
+## version that supports notches (based on patch from Mike Kay)
 
 panel.bwplot <-
     function(x, y, box.ratio = 1, box.width = box.ratio / (1 + box.ratio),
@@ -1060,7 +852,7 @@ panel.violin <-
     yscale <- current.panel.limits()$ylim
     height <- box.width # box.ratio / (1 + box.ratio)
 
-    if (hasArg(group.number))
+    if (hasGroupNumber())
         group <- list(...)$group.number
     else
         group <- 0
